// fancyprint.h
// Glenn G. Chappell
// 17 Sep 2013
// Header for class FancyPrint
// Class with a private member function

#ifndef FANCYPRINT_H
#define FANCYPRINT_H

#include <string>
using std::string;
#include <iostream>
using std::ostream;
using std::cout;
#include <cstdlib>
using std::size_t;


// class FancyPrint
// Holds a message (string) and a length. Prints the message in "fancy"
//  form, surrounded by asterisks: one line above and below, and a
//  number of asterisks to the left & right equal to length. The whole
//  terminated with a newline.
// For example, if the message is "Hello" and length is 3, then the
//  fancy form is as follows.
//
// *************
// *** Hello ***
// *************
class FancyPrint {

// ***** FancyPrint: ctors, dctor *****
public:

    // Ctor:
    // - 2 param from message & length
    // - 1 param from message, setting length to 1
    // - default ctor
    FancyPrint(string msg="", size_t len=1)
    {
        setMsg(msg);
        setLen(len);
    }

    // Compiler-generated dctor used

// ***** FancyPrint: general public functions *****
public:

    // Get & set functions for message
    string getMsg() const
    {
        return _msg;
    }
    void setMsg(string msg)
    {
        _msg = msg;
    }

    // Get & set functions for length
    size_t getLen() const
    {
        return _len;
    }
    void setLen(size_t len)
    {
        _len = len;
    }

    // print
    // Output message to the given stream, in "fancy" form, as described
    //  above.
    void print(ostream & out=cout) const;

// ***** FancyPrint: internal-use functions *****
private:

    // stars
    // Given an ostream and a number, prints that many asterisks to the
    //  stream. No newline is printed.
    void stars(ostream & out, size_t num) const;
   
// ***** FancyPrint: data members *****
private:

    string _msg;  // Message - string to print
    size_t _len;  // Length - number of asterisks to print before
                  //  & after message

};  // End class FancyPrint

#endif //#ifndef FANCYPRINT_H

